@@ -2,14 +2,14 @@ use strict;
 use warnings;
 
 package Message::String;
-our $VERSION = '0.1.8'; # VERSION
+our $VERSION = '0.1.9'; # VERSION
 # ABSTRACT: A pragma to declare and organise messaging.
 use Clone           ( 'clone' );
 use DateTime        ();
 use List::MoreUtils ( 'distinct' );
 use Scalar::Util    ( 'reftype' );
 use Sub::Util       ( 'set_subname' );
-use Term::ReadKey;
+use IO::Stty        ();
 use namespace::clean;
 use overload ( fallback => 1, '""' => 'to_string' );
 
@@ -28,7 +28,7 @@ BEGIN {
     sub C_BAD_MESSAGE_ID;
     sub C_MISSING_TEMPLATE;
 
-    # Messages come in eight basic flavours (or types):
+    # Messages types:
     #
     #  A (Severity 1: Alert)
     #  C (Severity 2: Critical)
@@ -514,9 +514,15 @@ BEGIN {
     {
         my ( $message ) = @_;
         print STDOUT "$message->{output}";
-        ReadMode( $message->readmode, \*Message::String::INPUT );
+        my $oldmode;
+        if ( $message->{readmode} ) {
+            $oldmode = IO::Stty::stty( \*Message::String::INPUT, '-g' );
+            IO::Stty::stty( \*Message::String::INPUT, $message->{readmode} );
+        }
         chomp( $message->{response} = <INPUT> );
-        ReadMode( 'normal', \*Message::String::INPUT );
+        if ( $oldmode ) {
+            IO::Stty::stty( \*Message::String::INPUT, $oldmode );
+        }
         $_ = $message->{response};
         return $message;
     }
@@ -1011,7 +1017,7 @@ sub _new
     $message->template( $message_template );
 
     if ( $message->type eq 'R' && $message->template =~ m{password}si ) {
-        $message->readmode( 'noecho' );
+        $message->readmode( '-echo' );
     }
     return $message;
 }
@@ -1141,7 +1147,7 @@ Message::String - A pragma to declare and organise messaging.
 
 =head1 VERSION
 
-version 0.1.8
+version 0.1.9
 
 =head1 SYNOPSIS
 
@@ -1644,15 +1650,14 @@ passed to the message.
 
 =head3 readmode
 
-    MESSAGE_ID->readmode( $mode_str );
-    MESSAGE_ID->readmode( $mode_int );
-    $mode_int = MESSAGE_ID->readmode;
+    MESSAGE_ID->readmode( $io_stty_sttymode_str );
+    $io_stty_sttymode_str = MESSAGE_ID->readmode;
 
-Uses L<C<Term::ReadKey>> to set the terminal driver mode when getting the
-response from C<STDIN>. The terminal driver mode is restored to its C<normal>
-state after the input is complete.
+Uses L<C<IO::Stty>> to set any special terminal driver modes when getting the
+response from C<STDIN>. The terminal driver mode will be restored to its
+normal state after the input has completed for the message.
 
-Ostensibly, this method is intended for use with Type R (Response) messages,
+This method is intended for use with Type R (Response) messages,
 specifically to switch off TTY echoing for password entry. You should,
 however, never need to use explicitly if the text I<"password"> is contained
 within the message's template, as its use is implied.
@@ -1661,7 +1666,7 @@ within the message's template, as its use is implied.
 
 =item B<Example>
 
-    RSP_MESSAGE->readmode('noecho');
+    RSP_MESSAGE->readmode('-echo');
 
 =back
 
@@ -2092,9 +2097,9 @@ For L<Scalar::Util> and L<Sub::Util>
 
 For L<List::MoreUtils>.
 
-=item Jonathon Stowe & Kenneth Albanowski
+=item Austin Schutz & Todd Rinaldo
 
-For L<Term::ReadKey>.
+For L<IO::Stty>.
 
 =item Ray Finch
 
