@@ -15,6 +15,12 @@ sub TIEHANDLE
     bless { fh => $fh, buffer => "" }, $class;
 }
 
+sub FILENO
+{
+    my ( $self ) = @_;
+    return fileno( $self->{fh} );
+}
+
 sub READLINE
 {
     my $self = shift;
